@@ -2,13 +2,14 @@
 #'
 #' The main function of the package \code{\link{trendsegmentR}}. This function estimates the number and locations of change-points in linear trend of noisy data. The estimated change-points may contain point anomalies (segments including only one data point) if any. It also returns the estimated signal, the best linear fit for each segment between a pair of adjacent change-points. The algorithm includes three steps, Tail-Greedy Unbalanced Wavelet (TGUW) transform (\code{\link{TGUW}}), thresholding (\code{\link{thresholding}}) and inverse TGUW transform (\code{\link{invTGUW}}).
 #'
-#' The algorithm is described in H. Maeng and P. Fryzlewicz (2021), Detecting linear trend changes in data sequences, preprint.
+#' The algorithm is described in H. Maeng and P. Fryzlewicz (2023), Detecting linear trend changes in data sequences.
 #'
 #' @param x A data vector to be examined for change-point detection.
-#' @param th.const Thresholding parameter used in \code{\link{thresholding}}. The default is 1.3 and the exact magnitude of the threshold is \code{sigma * th.const * sqrt(2 * log(n))} where \code{n} is the length of data sequence \code{x} and \code{sigma} is estimated by Median Absolute Deviation (MAD) method under the Gaussian assumption for noise.
-#' @param p Proportion of all possible remaining merges which specifies the number of merges allowed in a single pass over the data. This is used in \code{\link{TGUW}} and the default is 0.01.
-#' @param bal The minimum ratio of the length of the shorter region to the length of the entire merging region especially when the merges of Type 2 (merging one initial and a paired smooth coefficient) or of Type 3 (merging two sets of (paired) smooth coefficients) are performed. If \code{bal < 1/n} and \code{minsegL = 1}, point anomalies (segments including only one data point) can possibly be detected, otherwise, the detection of point anomalies is not guaranteed. The default is set to 0.
-#' @param minsegL The minimum segment length of estimated signal returned by \code{trendsegment}. The default is set to 5 for avoiding too frequent change-points.
+#' @param indep If x is known to be independent over time, let indep=TRUE, otherwise the default is indep=FALSE.
+#' @param th.const Robust thresholding parameter used in \code{\link{thresholding}}. The default is obtained by considering sample kurtosis and long run standard deviation. The exact magnitude of the threshold also depends on \code{sigma} which is estimated by Median Absolute Deviation (MAD) method under the i.i.d. Gaussian noise assumption.
+#' @param p Proportion of all possible remaining merges which specifies the number of merges allowed in a single pass over the data. This is used in \code{\link{TGUW}} and the default is 0.04.
+#' @param bal The minimum ratio of the length of the shorter region to the length of the entire merging region especially when the merges of Type 2 (merging one initial and a paired smooth coefficient) or of Type 3 (merging two sets of (paired) smooth coefficients) are performed. The default is set to 0.
+#' @param minsegL The minimum segment length of estimated signal returned by \code{trendsegment}. The default is set to \code{sigma * log(n)} for the noise which is possibly dependent and/or non-Gaussian.
 #' @param continuous If continuous=TRUE, the estimated signal returned by \code{trendsegment} is continuous at change-points, otherwise discontinuous at change-points. The default is set to FALSE.
 #' @param connected If connected=TRUE, the \code{trendsegment} algorithm puts the connected rule above the \code{minsegL}, otherwise it makes keeping the \code{minsegL} a priority. The default is set to FALSE.
 #' @return A list with the following.
@@ -16,27 +17,35 @@
 #' \item{est}{The estimated piecewise-linear signal of \code{x}.}
 #' \item{no.of.cpt}{The estimated number of change-points.}
 #' \item{cpt}{The estimated locations of change-points.}
-#' @author Hyeyoung Maeng \email{h.maeng4@@lancaster.ac.uk}, Piotr Fryzlewicz \email{p.fryzlewicz@@lse.ac.uk}
+#' @author Hyeyoung Maeng \email{hyeyoung.maeng@@durham.ac.uk}, Piotr Fryzlewicz \email{p.fryzlewicz@@lse.ac.uk}
 #' @seealso \code{\link{TGUW}}, \code{\link{thresholding}}, \code{\link{invTGUW}}
 #' @examples
 #' x <- c(rep(0,100), seq(0, 4, length.out = 100), rep(3, 100), seq(3, -1, length.out=99))
 #' n <- length(x)
 #' x <- x + rnorm(n)
-#' tsfit <- trendsegment(x = x, bal = 0)
+#' tsfit <- trendsegment(x = x)
 #' tsfit
 #'
 #' plot(x, type = "b", ylim = range(x, tsfit$est))
 #' lines(tsfit$est, col=2, lwd=2)
+#' abline(v=tsfit$cpt, col=3, lty=2, lwd=2)
 #' @importFrom stats mad
 #' @export
 
-trendsegment <- function(x, th.const = 1.3, p = .01, bal = 0, minsegL = 5, continuous = FALSE, connected = FALSE){
+trendsegment <- function(x, indep = FALSE, th.const = krt.hvt(x)$thr, p = .04, bal = 0, minsegL = floor(0.9*log(length(x))),
+                         continuous = FALSE, connected = FALSE){
 
   n <- length(x)
 
   # The estimator of the standard deviation of noise.
   # The default is obtained by Median Absolute Deviation (MAD) method under the Gaussian assumption for noise.
-  sigma <- stats::mad(diff(diff(x)))/sqrt(6)
+
+  if (indep == TRUE){
+    sigma <- stats::mad(diff(diff(x)))/sqrt(6)
+  }else{
+    sigma <- long.run.sd(x)
+  }
+
   lambda <- sigma * sqrt(2 * log(n)) * th.const
 
   if (n == 1) {
@@ -50,12 +59,12 @@ trendsegment <- function(x, th.const = 1.3, p = .01, bal = 0, minsegL = 5, conti
     x.d <- TGUW(x, p)
     x.d.d <- thresholding(x.d, lambda=lambda, bal=bal, minsegL=minsegL, connected=connected)
 
-    if(connected == FALSE){
+    if(connected == F){
 
       cpt <- finding.cp(x.d.d)
       no.of.cpt <- length(cpt)
 
-      if(continuous == FALSE){
+      if(continuous == F){
 
         est <- rep(NA, n)
         sgmts <- cbind(c(1, cpt+1), c(cpt, n))
@@ -80,7 +89,7 @@ trendsegment <- function(x, th.const = 1.3, p = .01, bal = 0, minsegL = 5, conti
 
       #x <- est$x
 
-      if(continuous == FALSE){
+      if(continuous == F){
 
         est <- est$ts.coeffs
 
